n treatment units and n matched control units. This power value is the expected fraction of truly differentially expressed genes that will be correctly declared as differentially expressed by the tests.power.matched(ER0, G0, absMu1, sigmad, n)sigmad) and the experimental error standard deviation (sigma) is sigmad=sqrt(2)/sigma.power.randomized,
power.multi,
sampleSize.randomized,
sampleSize.matchedpower.matched(ER0=2, G0=5000, absMu1=1, sigmad=0.4243, n=4)Run the code above in your browser using DataLab